from django.urls import reverse
from django.views.generic import (
    CreateView,
    UpdateView,
    DeleteView
)
from web.forms import CommentModelForm
from web.models import Comment


class CommentCreateView(CreateView):
    model = Comment
    template_name = 'comment/create_update.html'
    form_class = CommentModelForm

    def get_success_url(self):
        return reverse('articles-detail', kwargs={'id': self.object.article.id})


class CommentUpdateView(UpdateView):
    model = Comment
    template_name = 'comment/create_update.html'
    context_object_name = 'comment'
    pk_url_kwarg = 'id'
    form_class = CommentModelForm
    extra_context = {'button_text': 'Update', 'title': 'Update comment'}
    
    def get_initial(self):
        return self.object.__dict__

    def get_success_url(self):
        return reverse('articles-detail', kwargs={'id': self.object.article.id})


class CommentDeleteView(DeleteView):
    model = Comment
    pk_url_kwarg = 'id'

    def get_success_url(self):
        return reverse('articles-detail', kwargs={'id': self.object.article.id})
